// this function verifies disk space in kilobytes
function verifyDiskSpace(dirPath, spaceRequired)
{
  var spaceAvailable;

  // Get the available disk space on the given path
  spaceAvailable = fileGetDiskSpaceAvailable(dirPath);

  // Convert the available disk space into kilobytes
  spaceAvailable = parseInt(spaceAvailable / 1024);

  // do the verification
  if(spaceAvailable < spaceRequired)
  {
    logComment("Insufficient disk space: " + dirPath);
    logComment("  required : " + spaceRequired + " K");
    logComment("  available: " + spaceAvailable + " K");
    return(false);
  }

  return(true);
}

var srDest = 300;
var err;
var fChrome;

var themeName = "EarlyBlue";
var themeVersion = "1.0";
var chromeNode = themeName + "/" + themeVersion;
// --- END LOCALIZABLE RESOURCES ---
var regName    = "skins/mozilla/" + chromeNode;
var chromeName = themeName + ".jar";

err = initInstall(themeName, regName, themeVersion); 
logComment("initInstall: " + err);

fChrome = getFolder("Chrome");
logComment("fChrome: " + fChrome);

if (verifyDiskSpace(fChrome, srDest))
{
    var chromeType = SKIN;
    err = addFile(themeName, chromeName, fChrome, "");
    logComment("addFile() returned: " + err);

    if (err != SUCCESS)
    {
        logComment("addFile() to " + fChrome + "failed!");
 
        // couldn't install globally, try installing to the profile

        resetError();
        chromeType |= PROFILE_CHROME;
        fChrome = getFolder(getFolder("Profile"),"chrome");
        logComment("try installing to the user profile:" + fChrome);
        err = addFile(themeName, chromeName, fChrome, "");
    }
 
    setPackageFolder(fChrome);
 
    // check return value
    if ((err == SUCCESS) || (err == REBOOT_NEEDED))
    {
        var tellReboot = 0;
        if (err == REBOOT_NEEDED) {
           tellReboot = 1;
           resetError();
        }
        // register chrome
        var cf = getFolder(fChrome, chromeName);

        registerChrome(chromeType, cf, "");

        err = performInstall(); 
        logComment("performInstall() returned: " + err);
        if (err == REBOOT_NEEDED) {
           tellReboot = 1;
           resetError();
        }
        if (err == SUCCESS)
        {
           if (tellReboot == 1)
           {
               alert("Installation of " + themeName + " theme finished. You need to REBOOT your system before you are able to select to use this theme.");
           }
           else
           {
               alert("Installation of " + themeName + " theme finished successfully.");
           }
        }
        else
        {
               alert("Installation of " + themeName + " theme failed. Error code was " + err);
        }
    }
    else
    {
        cancelInstall(err);
        logComment("cancelInstall due to error: " + err);
        if (err == -202) {
           alert("Installation of " + themeName + " theme canceled with error " + err +". It seems you have no write permission to the Mozilla 'chrome' directory. Please install as root / system administrator.");
        }
        else {
           alert("Installation of " + themeName + " theme canceled. Error code was " + err);
        }
    }
}
else
    cancelInstall(INSUFFICIENT_DISK_SPACE);
